{#xhtmlxtras_dlg.attribs_title}

- {#xhtmlxtras_dlg.attribute_attrib_tab}
- {#xhtmlxtras_dlg.attribute_events_tab}

{#xhtmlxtras_dlg.attribute_attrib_tab}

{#xhtmlxtras_dlg.attribute_label_title}: |
{#xhtmlxtras_dlg.attribute_label_id}: |
{#class_name} |
{#xhtmlxtras_dlg.attribute_label_style}: |
{#xhtmlxtras_dlg.attribute_label_langdir}: |
{#xhtmlxtras_dlg.attribute_label_langcode}: |
{#xhtmlxtras_dlg.attribute_label_tabindex} |
{#xhtmlxtras_dlg.attribute_label_accesskey} |

{#xhtmlxtras_dlg.attribute_events_tab}

onfocus: |
onblur: |
onclick: |
ondblclick: |
onmousedown: |
onmouseup: |
onmouseover: |
onmousemove: |
onmouseout: |
onkeypress: |
onkeydown: |
onkeyup: |